
clear all
set more off
set matsize 5000


/*
        1. Tests (ttest and joint test)
*/

**From the stata data 

webuse auto,clear

desc

**Test foreign price = local price for cars
ttest price, by(foreign)

* price = β0 + β1foreign + β2length + u1
reg price foreign length
*β1=β2=0
test foreign length

** Test coefficients
test _b[foreign] =0

*β1+β2=0
test _b[foreign] +  _b[length] =0

**Create dymmy of the sample
reg price  length if foreign==1
gen reg_price_flag=e(sample)

* weight = γ0 + γ1foreign + γ2length + u2
reg weight foreign length

** Use sureg to test the effect of foreign (γ1=γ2)
sureg (price foreign length) (weight foreign length), small dfk
 
**Same equations
sureg (price weight = foreign length), small dfk

/*
        2. Simultaneity
*/

sureg (price foreign mpg displ) (weight foreign length)


/*
        3. Graphs with time
*/

global path "C:\Users\yaya1\Dropbox\Fall2020\ECON338\Stata Conference\Conference5"

use "$path\TsCanada.dta",clear
desc

** Number obs by year
tab year

** Number obs by province
tab prov

codebook prov,tabulate(10)

**Plot wage  by year for quebec
twoway (connected hrlyearn year if prov==24)

*Options
twoway (scatter hrlyearn year if prov==24), ytitle("Average wage rate") xtitle("year")

**Add Ontario
twoway (connected hrlyearn year if prov==24)(connected hrlyearn year if prov==35)

**Add legend
twoway (connected hrlyearn year if prov==24)(connected hrlyearn year if prov==35), legend(order(1 "Quebec" 2 "Ontario" ))

**change x-axis 
twoway (connected hrlyearn year if prov==24)(connected hrlyearn year if prov==35), legend(order(1 "Quebec" 2 "Ontario" )) xlabel(2000(2)2018)

twoway (connected hrlyearn year if prov==24)(connected hrlyearn year if prov==35), ///
legend(order(1 "Quebec" 2 "Ontario" )) xlabel(2000(2)2018) graphregion(color(white)) 


twoway (connected Unemployed year if prov==24)(connected Employed year if prov==24), ///
legend(order(1 "Unemployed" 2 "Employed" )) xlabel(2000(2)2018) graphregion(color(white)) 

twoway (connected Unemployed year if prov==24, yaxis(1) )(connected Employed year if prov==24, yaxis(2) ), ///
legend(order(1 "Unemployed" 2 "Employed" )) xlabel(2000(2)2018) graphregion(color(white)) 


/*
        4. Loops
*/

foreach province of numlist 10 11 24 35 {
tab prov if prov==`province'
reg Employed hrlyearn if prov==`province'
}




